aboutsummaryrefslogtreecommitdiffstats
path: root/yage/base/window.h
diff options
context:
space:
mode:
authorYann Herklotz <ymherklotz@gmail.com>2017-09-22 00:02:59 +0100
committerYann Herklotz <ymherklotz@gmail.com>2017-09-22 00:02:59 +0100
commit5deb18b72a4993a4baf59b7da24a04116eab31e6 (patch)
treec7a1523bed9bf7629b311d63e212957a6ae735be /yage/base/window.h
parent34396f0483d94229e3a315e5eeb90c77c1425273 (diff)
parente8208166c67e564fb249aa41e9f8c5e2fa1f2b9a (diff)
downloadYAGE-5deb18b72a4993a4baf59b7da24a04116eab31e6.tar.gz
YAGE-5deb18b72a4993a4baf59b7da24a04116eab31e6.zip
Merge branch 'develop'
Diffstat (limited to 'yage/base/window.h')
-rw-r--r--yage/base/window.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/yage/base/window.h b/yage/base/window.h
index 8639e075..eb4cf005 100644
--- a/yage/base/window.h
+++ b/yage/base/window.h
@@ -6,10 +6,13 @@
* ----------------------------------------------------------------------------
*/
+/** @file
+ */
+
#ifndef WINDOW_H
#define WINDOW_H
-#include <SDL2/SDL.h>
+#include <GLFW/glfw3.h>
#include <string>
@@ -24,12 +27,12 @@ enum WindowFlags : unsigned {
BORDERLESS = 0x8,
};
// window wrapper around SDL_Window pointer
class Window
{
private:
/// window handle
- SDL_Window *window_ = nullptr;
+ GLFWwindow *window_ = nullptr;
public:
Window();
@@ -24,12 +27,12 @@ enum WindowFlags : unsigned {
BORDERLESS = 0x8,
};
-// window wrapper around SDL_Window pointer
+// window wrapper around GLFWwindow pointer
class Window
{